summaryrefslogtreecommitdiff
path: root/vendor/github.com/openshift/api/config/v1/types_operatorhub.go
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2020-01-22 10:10:54 +0100
committerGitHub <noreply@github.com>2020-01-22 10:10:54 +0100
commitd52132b6ecc1c1c9fb955ecee629f8d169ef1119 (patch)
tree407913f45dea2c2089d66b223fb32b15065c42c1 /vendor/github.com/openshift/api/config/v1/types_operatorhub.go
parentaa13779e9e8d5bb6090d514e3aad9387cb0a2d35 (diff)
parenta0c5762fe886b9b2e0c73cb0639d18096f9c8ade (diff)
downloadpodman-d52132b6ecc1c1c9fb955ecee629f8d169ef1119.tar.gz
podman-d52132b6ecc1c1c9fb955ecee629f8d169ef1119.tar.bz2
podman-d52132b6ecc1c1c9fb955ecee629f8d169ef1119.zip
Merge pull request #4919 from vrothberg/fix-mod
go.mod: fix parse error
Diffstat (limited to 'vendor/github.com/openshift/api/config/v1/types_operatorhub.go')
-rw-r--r--vendor/github.com/openshift/api/config/v1/types_operatorhub.go19
1 files changed, 14 insertions, 5 deletions
diff --git a/vendor/github.com/openshift/api/config/v1/types_operatorhub.go b/vendor/github.com/openshift/api/config/v1/types_operatorhub.go
index cf821f9e3..1d998bf37 100644
--- a/vendor/github.com/openshift/api/config/v1/types_operatorhub.go
+++ b/vendor/github.com/openshift/api/config/v1/types_operatorhub.go
@@ -6,10 +6,19 @@ import (
// OperatorHubSpec defines the desired state of OperatorHub
type OperatorHubSpec struct {
+ // disableAllDefaultSources allows you to disable all the default hub
+ // sources. If this is true, a specific entry in sources can be used to
+ // enable a default source. If this is false, a specific entry in
+ // sources can be used to disable or enable a default source.
+ // +optional
+ DisableAllDefaultSources bool `json:"disableAllDefaultSources,omitempty"`
// sources is the list of default hub sources and their configuration.
// If the list is empty, it indicates that the default hub sources are
// enabled on the cluster. The list of default hub sources and their
// current state will always be reflected in the status block.
// +optional
Sources []HubSource `json:"sources,omitempty"`
}
@@ -61,9 +70,9 @@ type HubSource struct {
// HubSourceStatus is used to reflect the current state of applying the
// configuration to a default source
type HubSourceStatus struct {
- HubSource
+ HubSource `json:",omitempty"`
// status indicates success or failure in applying the configuration
- Status string `json:"status"`
+ Status string `json:"status,omitempty"`
// message provides more information regarding failures
Message string `json:"message,omitempty"`
}
@@ -6,10 +6,19 @@ import (
// sources is the list of default hub sources and their configuration.
- // If the list is empty, it indicates that the default hub sources are
- // enabled on the cluster. The list of default hub sources and their
- // current state will always be reflected in the status block.
+ // If the list is empty, it implies that the default hub sources are
+ // enabled on the cluster unless disableAllDefaultSources is true.
+ // If disableAllDefaultSources is true and sources is not empty,
+ // the configuration present in sources will take precedence. The list of
+ // default hub sources and their current state will always be reflected in
+ // the status block.
// +optional
Sources []HubSource `json:"sources,omitempty"`